# design-explorer

<div align="center">
  <!-- Build Status -->
  <a href="https://travis-ci.org/jeremiah-c-leary/design-explorer">
    <img src="https://img.shields.io/travis/jeremiah-c-leary/design-explorer/master.svg?style=flat-square"
      alt="Build Status" />
  </a>
  <!-- Test Coverage -->
  <a href="https://codecov.io/github/jeremiah-c-leary/design-explorer">
    <img src="https://img.shields.io/codecov/c/github/jeremiah-c-leary/design-explorer/master.svg?style=flat-square"
      alt="Test Coverage" />
  </a>
  <!-- Codacy -->
  <a class="badge-align" href="https://www.codacy.com/app/jeremiah-c-leary/design-explorer?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=jeremiah-c-leary/design-explorer&amp;utm_campaign=Badge_Grade">
    <img src="https://api.codacy.com/project/badge/Grade/42744dca97544824b93cfc99e8030063"
      alt="Codacy" />
  </a>
  <!-- Code Climate -->
  <a href="https://codeclimate.com/github/jeremiah-c-leary/design-explorer/maintainability">
    <img src="https://api.codeclimate.com/v1/badges/2815689ec945a2f70a24/maintainability"i
      alt="Code Climate" />
  </a>
</div>
